"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const neverthrow_1 = require("neverthrow");
const react_1 = __importDefault(require("react"));
const react_dom_1 = __importDefault(require("react-dom"));
const constants_1 = require("../../constants");
const MainContainer_1 = require("../../containers/MainContainer");
const contexts_1 = require("../../contexts");
const ConnectorAuthorizationFlow_1 = __importDefault(require("../../flows/ConnectorAuthorizationFlow"));
const PrivateKeysFlow_1 = __importDefault(require("../../flows/PrivateKeysFlow"));
const BalancesWidget_1 = __importDefault(require("../../widgets/BalancesWidget"));
const FundWidget_1 = __importDefault(require("../../widgets/FundWidget"));
const LinksWidget_1 = __importDefault(require("../../widgets/LinksWidget"));
const PaymentWidget_1 = require("../../widgets/PaymentWidget");
class HypernetWebUI {
    constructor(coreInstance) {
        this.coreInstance = coreInstance;
        if (!coreInstance && !window.hypernetCoreInstance) {
            throw new Error("core instance is required");
        }
        if (window.hypernetCoreInstance) {
            this.coreInstance = window.hypernetCoreInstance;
        }
        console.log("this.coreInstance: ", this.coreInstance);
    }
    _generateDomElement(selector) {
        this._removeExistedElement(selector);
        const element = document.createElement("div");
        element.setAttribute("id", selector);
        document.body.appendChild(element);
        document.getElementById(selector);
        return element;
    }
    _removeExistedElement(selector) {
        const element = document.getElementById(selector);
        if (element) {
            element.remove();
        }
    }
    _bootstrapComponent(component, withModal = false) {
        if (!this.coreInstance) {
            throw new Error("core instance is required");
        }
        return (react_1.default.createElement(contexts_1.StoreProvider, { proxy: this.coreInstance },
            react_1.default.createElement(contexts_1.LayoutProvider, null,
                react_1.default.createElement(MainContainer_1.MainContainer, { withModal: withModal }, component))));
    }
    _getThrowableRender(renderReact) {
        const throwable = neverthrow_1.Result.fromThrowable(renderReact, (err) => {
            return err;
        });
        return throwable();
    }
    renderPrivateKeysModal() {
        const renderReact = () => {
            return react_dom_1.default.render(this._bootstrapComponent(react_1.default.createElement(PrivateKeysFlow_1.default, null), true), this._generateDomElement(constants_1.PRIVATE_KEYS_FLOW_ID_SELECTOR));
        };
        return this._getThrowableRender(renderReact);
    }
    renderBalancesWidget(config) {
        const renderReact = () => {
            return react_dom_1.default.render(this._bootstrapComponent(react_1.default.createElement(BalancesWidget_1.default, null), config === null || config === void 0 ? void 0 : config.showInModal), this._generateDomElement((config === null || config === void 0 ? void 0 : config.selector) || constants_1.BALANCES_WIDGET_ID_SELECTOR));
        };
        return this._getThrowableRender(renderReact);
    }
    renderFundWidget(config) {
        const renderReact = () => {
            return react_dom_1.default.render(this._bootstrapComponent(react_1.default.createElement(FundWidget_1.default, null), config === null || config === void 0 ? void 0 : config.showInModal), this._generateDomElement((config === null || config === void 0 ? void 0 : config.selector) || constants_1.FUND_WIDGET_ID_SELECTOR));
        };
        return this._getThrowableRender(renderReact);
    }
    renderLinksWidget(config) {
        const renderReact = () => {
            return react_dom_1.default.render(this._bootstrapComponent(react_1.default.createElement(LinksWidget_1.default, null), config === null || config === void 0 ? void 0 : config.showInModal), this._generateDomElement((config === null || config === void 0 ? void 0 : config.selector) || constants_1.LINKS_WIDGET_ID_SELECTOR));
        };
        return this._getThrowableRender(renderReact);
    }
    renderPaymentWidget(config) {
        const renderReact = () => {
            return react_dom_1.default.render(this._bootstrapComponent(react_1.default.createElement(PaymentWidget_1.PaymentWidget, { counterPartyAccount: config === null || config === void 0 ? void 0 : config.counterPartyAccount, amount: config === null || config === void 0 ? void 0 : config.amount, expirationDate: config === null || config === void 0 ? void 0 : config.expirationDate, requiredStake: config === null || config === void 0 ? void 0 : config.requiredStake, paymentTokenAddress: config === null || config === void 0 ? void 0 : config.paymentTokenAddress, merchantUrl: config === null || config === void 0 ? void 0 : config.merchantUrl, paymentType: config === null || config === void 0 ? void 0 : config.paymentType }), config === null || config === void 0 ? void 0 : config.showInModal), this._generateDomElement((config === null || config === void 0 ? void 0 : config.selector) || constants_1.PAYMENT_WIDGET_ID_SELECTOR));
        };
        return this._getThrowableRender(renderReact);
    }
    renderConnectorAuthorizationFlow(config) {
        const renderReact = () => {
            return react_dom_1.default.render(this._bootstrapComponent(react_1.default.createElement(ConnectorAuthorizationFlow_1.default, { connectorUrl: config.connectorUrl, connectorName: config.connectorName, connectorLogoUrl: config.connectorLogoUrl }), config.showInModal), this._generateDomElement((config === null || config === void 0 ? void 0 : config.selector) || constants_1.CONNECTOR_AUTHORIZATION_FLOW));
        };
        return this._getThrowableRender(renderReact);
    }
    displayMerchantIFrame(merchantUrl) {
        var _a;
        (_a = this.coreInstance) === null || _a === void 0 ? void 0 : _a.displayMerchantIFrame(merchantUrl);
    }
    closeMerchantIFrame(merchantUrl) {
        var _a;
        (_a = this.coreInstance) === null || _a === void 0 ? void 0 : _a.closeMerchantIFrame(merchantUrl);
    }
}
exports.default = HypernetWebUI;
window.HypernetWebUI = HypernetWebUI;
//# sourceMappingURL=HypernetWebUI.js.map